package util

import "sync"

// LockingUint64 is a lockable uint64
type LockingUint64 struct {
	sync.RWMutex
	data uint64
}

// NewLockingUint64 creates a new locking uint64
func NewLockingUint64() LockingUint64 {
	return LockingUint64{}
}

// Set will lock and set the value of a lockingUint64
func (i *LockingUint64) Set(val uint64) {
	i.Lock()
	defer i.Unlock()
	i.data = val
}

// AddOne will lock and increment a lockingUint64
func (i *LockingUint64) AddOne() {
	i.Set(i.Get() + 1)
}

// Get will Rlock and return the value of a lockingUint64
func (i *LockingUint64) Get() uint64 {
	i.RLock()
	defer i.RUnlock()
	return i.data
}
